# Authors of this project

Sorted list of authors derived from git commit history:
```
Andreas Maier <andreas.r.maier@gmx.de>
Bart Whiteley <bwhiteley@gmail.com>
Claudio Kuenzler <claudio.kuenzler@infiniroot.com>
Jan Safranek <jsafrane@redhat.com>
Jon Carey <unknown@unknown.org>
Karl Schopmeyer <karl.schopmeyer@gmail.com>
Michal Minar <miminar@redhat.com>
Norm Paxton <unknown@unknown.org>
Tim Potter <tpot@hp.com>
Tony <23.tony@gmail.com>
Tony Asleson <tasleson@redhat.com>
Will Spearman <wspearman@sciencelogic.com>
pyup-bot <github-bot@pyup.io>
```
